Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2927)

Unified Diff: base/trace_event/trace_config.cc

Issue 1479443002: Fixed an issue where tracing events got incorrectly enabled. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 5 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | base/trace_event/trace_config_unittest.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: base/trace_event/trace_config.cc
diff --git a/base/trace_event/trace_config.cc b/base/trace_event/trace_config.cc
index 7124bea8bf6a1cb0ea1a4bbbf29dfc4b52287c6c..e15d274f18e85b620a69ad662b896f27127b16c5 100644
--- a/base/trace_event/trace_config.cc
+++ b/base/trace_event/trace_config.cc
@@ -209,9 +209,13 @@ bool TraceConfig::IsCategoryGroupEnabled(
break;
}
// One of the category of category_group_name is not present in
- // excluded_ list. So, it has to be included_ list. Enable the
- // category_group_name for recording.
- category_group_disabled = false;
+ // excluded_ list. So, if it's not a disabled-by-default category,
+ // it has to be included_ list. Enable the category_group_name
+ // for recording.
+ if (!base::MatchPattern(category_group_token.c_str(),
+ TRACE_DISABLED_BY_DEFAULT("*"))) {
+ category_group_disabled = false;
+ }
}
// One of the categories present in category_group_name is not present in
// excluded_ list. Implies this category_group_name group can be enabled
« no previous file with comments | « no previous file | base/trace_event/trace_config_unittest.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698